#! /usr/bin/env python
# This file is part of the program FRYSK.
#
# Copyright 2005, 2006, Red Hat Inc.
#
# FRYSK is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 of the License.
#
# FRYSK is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
# General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with FRYSK; if not, write to the Free Software Foundation,
# Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
# 
# In addition, as a special exception, Red Hat, Inc. gives You the
# additional right to link the code of FRYSK with code not covered
# under the GNU General Public License ("Non-GPL Code") and to
# distribute linked combinations including the two, subject to the
# limitations in this paragraph. Non-GPL Code permitted under this
# exception must only link to the code of FRYSK through those well
# defined interfaces identified in the file named EXCEPTION found in
# the source code files (the "Approved Interfaces"). The files of
# Non-GPL Code may instantiate templates or use macros or inline
# functions from the Approved Interfaces without causing the
# resulting work to be covered by the GNU General Public
# License. Only Red Hat, Inc. may make changes or additions to the
# list of Approved Interfaces. You must obey the GNU General Public
# License in all respects for all of the FRYSK code and other code
# used in conjunction with FRYSK except the Non-GPL Code covered by
# this exception. If you modify this file, you may extend this
# exception to your version of the file, but you are not obligated to
# do so. If you do not wish to provide this exception without
# modification, you must delete this exception statement from your
# version and license this file solely under the GPL without
# exception.

"""
Script name:    frysk_suite.py
Creation date:  April 2006
Purpose:        Organize the Dogtail/Frysk test scripts
Summary:        Still a prototype
"""

__author__ = 'Len DiMaggio <ldimaggi@redhat.com>'

try:
    frysk
except NameError:
    frysk="/builddir/build/BUILD/build-frysk-0.0.1.2007.08.03/frysk-0.0.1.2007.08.03/frysk-gui/frysk/gui/FryskGui"
    src="/builddir/build/BUILD/frysk-0.0.1.2007.08.03/frysk-gui/frysk/gui/test/dogtail_scripts/"
    funitChild="/builddir/build/BUILD/build-frysk-0.0.1.2007.08.03/frysk-0.0.1.2007.08.03/frysk-gui/../frysk-core/frysk/pkglibdir/funit-child"

# Import needed to access test file input files via envron var's
import os
import sys
# Needed to be able to run the scripts from the source tree when this script
# is in the build tree
sys.path.append(src)

# Import the test suites
import unittest
import license
import credits
import druid
import observerData
import test2866
import test2985
import test3380
import stressDruid
import guiWalkTest
import eventViewerAccessibilityInfo

from dogtail import version
from dogtail import distro

# Define the test input files
os.environ.__setitem__('TestDruid_FILE', src + 'another_new_session.xml')
os.environ.__setitem__('fryskBinary', frysk)
os.environ.__setitem__('funitChild', funitChild)
os.environ.__setitem__('fryskDataDir', src)

# Define the suite elements
licenseSuite = license.suite()
creditsSuite = credits.suite()
druidSuite = druid.suite()
observerSuite = observerData.suite()
test2866Suite = test2866.suite()
test2985Suite = test2985.suite()
test3380Suite = test3380.suite()
stressDruidSuite = stressDruid.suite()
guiWalkTestSuite = guiWalkTest.suite()

# Assemble the suite
suite = unittest.TestSuite()
suite.addTest(licenseSuite)
suite.addTest(creditsSuite)
suite.addTest(druidSuite)
suite.addTest(observerSuite)
suite.addTest(test2866Suite)
suite.addTest(test2985Suite)
suite.addTest(eventViewerAccessibilityInfo)
# Commented out - test aborts as of 20060926 - bug #2807
# suite.addTest(stressDruidSuite)
suite.addTest(guiWalkTestSuite)
# Commented out - test aborts as of 20061019 - bug #3380
# suite.addTest(test3380Suite)

#check dogtail version
dogtailVersion = distro.packageDb.getVersion("dogtail")
        
if dogtailVersion < distro.Version.fromString("0.6.1"):
    print "these tests are not compatable with dogtail version ", dogtailVersion
    print "version 0.6.1 or higher required ", dogtailVersion
    sys.exit();
                
# Run the test suite
unittest.TextTestRunner(verbosity=2).run(suite)

# Cleanup
os.environ.__delitem__('TestDruid_FILE')
os.environ.__delitem__('fryskBinary')
os.environ.__delitem__('funitChild')
os.environ.__delitem__('fryskDataDir')

